@@ -17,7 +17,7 @@ def handle(data, secrets, function_call_info):
       if data:
          output = service(data, secrets)
       else:
-         output = {}
+         output = dict(status='ok')
       cdf.api_keys = secrets
       cdf.set_up_cdf_client(context='deploy')
       metadata = cdf.get_function_metadata(function_call_info["function_id"])
